.. include:: ./refs.rst

.. _reference:

=========
Reference
=========

.. _base:

.. automodule:: django_routines
   :members:
   :show-inheritance:
   :inherited-members:

exceptions
----------

.. automodule:: django_routines.exceptions
    :members:
    :show-inheritance:

routine command
---------------

.. automodule:: django_routines.management.commands.routine
    :members:
    :show-inheritance:
